#[repr(C)]pub struct LauncherLaunchResponse {
pub return_code: i64,
}Fields
return_code: i64Trait Implementations
Sourceimpl Clone for LauncherLaunchResponse
impl Clone for LauncherLaunchResponse
Sourcefn clone(&self) -> LauncherLaunchResponse
fn clone(&self) -> LauncherLaunchResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LauncherLaunchResponse
impl Debug for LauncherLaunchResponse
Sourceimpl<D: ResourceDialect> Decode<LauncherLaunchResponse, D> for LauncherLaunchResponse
impl<D: ResourceDialect> Decode<LauncherLaunchResponse, D> for LauncherLaunchResponse
Sourceimpl<D: ResourceDialect> Encode<LauncherLaunchResponse, D> for &LauncherLaunchResponse
impl<D: ResourceDialect> Encode<LauncherLaunchResponse, D> for &LauncherLaunchResponse
Sourceimpl<D: ResourceDialect, T0: Encode<i64, D>> Encode<LauncherLaunchResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<i64, D>> Encode<LauncherLaunchResponse, D> for (T0,)
Sourceimpl Hash for LauncherLaunchResponse
impl Hash for LauncherLaunchResponse
Sourceimpl Ord for LauncherLaunchResponse
impl Ord for LauncherLaunchResponse
Sourcefn cmp(&self, other: &LauncherLaunchResponse) -> Ordering
fn cmp(&self, other: &LauncherLaunchResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LauncherLaunchResponse
impl PartialEq for LauncherLaunchResponse
Sourceimpl PartialOrd for LauncherLaunchResponse
impl PartialOrd for LauncherLaunchResponse
Sourceimpl TypeMarker for LauncherLaunchResponse
impl TypeMarker for LauncherLaunchResponse
Sourcetype Owned = LauncherLaunchResponse
type Owned = LauncherLaunchResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for LauncherLaunchResponse
impl ValueTypeMarker for LauncherLaunchResponse
Sourcetype Borrowed<'a> = &'a LauncherLaunchResponse
type Borrowed<'a> = &'a LauncherLaunchResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for LauncherLaunchResponse
impl Eq for LauncherLaunchResponse
impl Persistable for LauncherLaunchResponse
impl StructuralPartialEq for LauncherLaunchResponse